sphinx.ext.coverage – Collect doc coverage stats — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# `sphinx.ext.coverage` – Collect doc coverage stats

This extension features one additional builder, the `CoverageBuilder`.

class `sphinx.ext.coverage.` `CoverageBuilder`

  To use this builder, activate the coverage extension in your configuration file and give `-b coverage` on the command line.

Several new configuration values can be used to specify what the builder should check:

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »